@@ -2,5 +2,5 @@ from easyprocess import EasyProcess
 from pyvirtualdisplay import Display
  
 Display(visible=1, size=(320, 240)).start()
-EasyProcess('abiword').start()
+EasyProcess('gnumeric').start()
 
