@@ -19,11 +19,9 @@ class SmartDisplay(Display):
     def autocrop(self, im):
         '''Crop borders off an image.
     
-         :param im: Source image.
-         :param bgcolor: Background color, using either a color tuple or
-         a color name (1.1.4 only).
-         :return: An image without borders, or None if there's no actual
-         content in the image.
+        :param im: Source image.
+        :param bgcolor: Background color, using either a color tuple or a color name (1.1.4 only).
+        :return: An image without borders, or None if there's no actual content in the image.
         '''
         if im.mode != "RGB":
             im = im.convert("RGB")
@@ -40,7 +38,7 @@ class SmartDisplay(Display):
             img = self.autocrop(img)
         return img
         
-    def waitgrab(self, timeout=10, autocrop=True, cb_imgcheck=None):
+    def waitgrab(self, timeout=60, autocrop=True, cb_imgcheck=None):
         '''start process and create screenshot.
         Repeat screenshot until it is not empty and 
         cb_imgcheck callback function returns True 
